/*
  * Copyright (C) 2006-2011 Nokia Corporation.
  *
  * This file is part of devicelock
  *
  * Authors: Brian McGillion <brian.mcgillion@symbio.com>,
  * 	     Denis Mingulov  <denis.mingulov@symbio.com>
  *
  */

/*!
  * \file lockuisignals.h
  * \author Brian McGillion <brian.mcgillion@symbio.com>
  * \class LockuiSignals
  * \brief This class provides a mechanism for marshaling signals between the plugin and the daemon.
  */

#ifndef LOCKUISIGNALS_H
#define LOCKUISIGNALS_H

#include <QtCore/QObject>

class LockuiSignals : public QObject
{
    Q_OBJECT
public:

    /*!
      * \brief Constructor
      * \param parent The parent of this object
      */
    explicit LockuiSignals(QObject *parent) : QObject(parent) {}

    /*!
      * \brief Destructor
      */
    ~LockuiSignals() {}

signals:

    /*!
      * \brief Allow the LockUI plugin request the daemon to sent the password recovery text to the trusted contact
      */
    void sendRecoveryText();

    /*!
      * \brief This is the clear text password that the user has entered
      * \param password The password that is to be verified.
      */
    void checkUserPassword(const QString &password);

    /*!
      * \brief Cancel the password prompt dialog
      */
    void cancel();

    /*!
      * \brief A signal to notify that the password that was supplied by the user was invalid.
      * \param result The result of the password verification attempt, true if password is correct, false otherwise.
      * \param attemptsLeft The number of attempts the user has left before the device is bricked.
      */
    void passwordValidationResult(bool result, unsigned int attemptsLeft);

    /*!
      * \brief Change the users password.
      * \param old The old password to use
      * \param newPass The newwPassword To replace it with
      */
    void changePassword(const QString &old, const QString &newPass);

    /*!
      * \brief a signal to notify the plugin that the password change was not successful
      * \param result The result of the password change request. Empty if password is changed
      */
    void changePasswordResult(const QString &result);
};

#endif // LOCKUISIGNALS_H
