/*
  * Copyright (C) 2006-2011 Nokia Corporation.
  *
  * This file is part of devicelock
  *
  * Authors: Brian McGillion <brian.mcgillion@symbio.com>,
  * 	     Denis Mingulov  <denis.mingulov@symbio.com>
  *
  */

#ifndef LOGGING_H
#define LOGGING_H


#include <syslog.h>
#include <sys/types.h>
#include <unistd.h>
#include <QtCore/QDebug>
#include <QtCore/QString>
#include <QtCore/QDateTime>
#include <QtCore/QThread>

#if !defined(QT_NO_DEBUG_OUTPUT) && !defined(QT_NO_WARNING_OUTPUT)

/*!
 * \def LOG
 * \param priority Is the error level of the message
 * \param message The error Message to report
 * \param arg parameters for message
 */
#define LOG(priority, message, arg...) \
do { \
    if (priority <= LOG_CRIT) \
        qCritical("%d: %s:%s:%d: " message, priority, __FILE__, __FUNCTION__, __LINE__, ##arg); \
    else if (priority <= LOG_WARNING) \
        qWarning("%d: %s:%s:%d: " message, priority, __FILE__, __FUNCTION__, __LINE__, ##arg); \
    else \
        qDebug("%d: %s:%s:%d: " message, priority, __FILE__, __FUNCTION__, __LINE__, ##arg); \
} while(0)

/*!
  * \def LOG_RETURN
  * \param priority Is the error level of the message
  * \param _retval The value to return from the method with
  * \param message The error Message to report
  * \param arg parameters for message
  */
#define LOG_RETURN(priority, _retval, message, arg...) \
do { \
        LOG(priority, message, ##arg); \
        return _retval; \
   } while(0)


#else

#define LOG(priority, message, arg...) do {} while(0)
#define LOG_RETURN(priority, _retval, message, arg...) do { return _retval; } while(0)

#endif

#define LOG_OFF(priority, message, arg...) do {} while(0)
#define LOG_RETURN_OFF(priority, _retval, message, arg...) do { return _retval; } while(0)

#endif // LOGGING_H
