/*
  * Copyright (C) 2006-2011 Nokia Corporation.
  *
  * This file is part of devicelock
  *
  * Authors: Brian McGillion <brian.mcgillion@symbio.com>,
  * 	     Denis Mingulov  <denis.mingulov@symbio.com>
  *
  */

#ifndef SHARED_SETTINGS_H
#define SHARED_SETTINGS_H

#include <QtCore/QLatin1String>

namespace PasswordStr
{
    //Constant strings
    static const QLatin1String Category ("Password");
    static const QLatin1String PasswordControler ("Password::PasswordControler");
    static const QLatin1String PasswordSettings ("Password::PasswordSettings");
    static const QLatin1String VerifyAndChange ("Password::VerifyAndChange");

    static const QLatin1String EncryptedPassword ("Password::EncryptedPassword");
    static const QLatin1String History ("Password::History");
    static const QLatin1String FailedAttempts ("Password::FailedAttempts");
    static const QLatin1String FailedAttemptsLeft ("Password::FailedAttemptsLeft");
    static const QLatin1String PasswordSalt ("Password::PasswordSalt");
    static const QLatin1String SSOPassword ("Password::SSOPassword");
    static const QLatin1String PasswordHash ("Password::PasswordHash");
    static const QLatin1String IsPasswordSet ("Password::IsPasswordSet");
    static const QLatin1String PasswordLength ("Password::PasswordLength");
    static const QLatin1String IsPasswordSimple ("Password::IsPasswordSimple");
    static const QLatin1String IsPasswordAlphaNumeric ("Password::IsPasswordAlphaNumeric");
    static const QLatin1String PasswordComplexChars ("Password::PasswordComplexChars");
    static const QLatin1String IsPasswordExpired ("Password::IsPasswordExpired");
    //! Check - is password expired or not
    static const QLatin1String CheckIsPasswordExpired ("Password::CheckIsPasswordExpired");

    static const QLatin1String CurrentPassword ("Password::CurrentPassword");
    static const QLatin1String NewPassword ("Password::NewPassword");
    static const QLatin1String Result ("Password::Result");

    //some settings that are actually just commands, so can be passed easier than having to use signals everywhere.

}

namespace ProvisioningStr
{
    static const QLatin1String Category ("Provisioning");
    static const QLatin1String ProvisioningControler ("Provisioning::ProvisioningControler");
    static const QLatin1String ProvisioningSettings ("ProvisioningSettings");
    static const QLatin1String SettingsCurrent ("Provisioning::Current");
    static const QLatin1String SettingsStored ("Provisioning::Stored");
    static const QLatin1String SettingsRequested ("Provisioning::Requested");
    static const QLatin1String SettingsQueued ("Provisioning::Queued");

    // fields
    static const QLatin1String SettingsEntitySender ("Provisioning::EntitySender");
    static const QLatin1String SettingsEntitySenderId("Provisioning::EntitySenderId");

    static const QLatin1String RemovalEntity ("Provisioning::RemovalEntity");

    static const QLatin1String DevicePasswordRequired ("Provisioning::DevicePasswordRequired");
    static const QLatin1String MinDevicePasswordLength ("Provisioning::MinDevicePasswordLength");
    static const QLatin1String AllowSimpleDevicePassword ("Provisioning::AllowSimpleDevicePassword");
    static const QLatin1String AlphaNumericDevicePasswordRequired ("Provisioning::AlphaNumericDevicePasswordRequired");
    static const QLatin1String MinDevicePasswordComplexCharacters ("Provisioning::MinDevicePasswordComplexCharacters");
    static const QLatin1String MaxInactivityTimeDeviceLock ("Provisioning::MaxInactivityTimeDeviceLock");
    static const QLatin1String MaxDevicePasswordFailedAttempts ("Provisioning::MaxDevicePasswordFailedAttempts");
    static const QLatin1String DevicePasswordExpiration ("Provisioning::DevicePasswordExpiration");
    static const QLatin1String DevicePasswordHistory ("Provisioning::DevicePasswordHistory");
    static const QLatin1String DevicePasswordForceChange ("Provisioning::DevicePasswordForceChange");
    static const QLatin1String MinimalDeviceWipeTypeRequired ("Provisioning::MinimalDeviceWipeTypeRequired");
    static const QLatin1String AllowRemoteSecurity ("Provisioning::AllowRemoteSecurity");
    static const QLatin1String SetDevicePassword ("Provisioning::SetDevicePassword");
    static const QLatin1String ForceAccept ("Provisioning::ForceAccept");
    // additional labels for
    static const QLatin1String SenderHeaderLabel ("Provisioning::SenderHeaderLabel");

    //! amount of entities counted for this setting detail
    static const QLatin1String TotalEntities ("Provisioning::TotalEntities");

    // security
    namespace SecurityToken
    {
        static const QLatin1String DevicePasswordForceChange ("Provisioning::SecurityToken::DevicePasswordForceChange");
        static const QLatin1String MinimalDeviceWipeTypeRequired ("Provisioning::SecurityToken::MinimalDeviceWipeTypeRequired");
    }

    // limits
    namespace Limit
    {
        static const QLatin1String ValueType ("Provisioning::Limit::ValueType");
        static const QLatin1String AllowedValues ("Provisioning::Limit::AllowedValues");

        namespace Min
        {
            static const QLatin1String MaxInactivityTimeDeviceLock ("Provisioning::Limit::MaxInactivityTimeDeviceLock::Min");
            static const QLatin1String MinDevicePasswordLength ("Provisioning::Limit::MinDevicePasswordLength::Min");
            static const QLatin1String MinDevicePasswordComplexCharacters ("Provisioning::Limit::MinDevicePasswordComplexCharacters::Min");
            static const QLatin1String MinimalDeviceWipeTypeRequired ("Provisioning::Limit::MinimalDeviceWipeTypeRequired::Min");
            static const QLatin1String DevicePasswordHistory ("Provisioning::Limit::DevicePasswordHistory::Min");
        }
        namespace Max
        {
            static const QLatin1String MinimalDeviceWipeTypeRequired ("Provisioning::Limit::MinimalDeviceWipeTypeRequired::Max");
            static const QLatin1String MinDevicePasswordLength ("Provisioning::Limit::MinDevicePasswordLength::Max");
        }
    }
}

namespace ConfigurationsStr
{
    static const QLatin1String Category ("Configurations");
    static const QLatin1String ConfigurationControler ("Configurations::ConfigurationControler");
    static const QLatin1String ConfigurationSettings ("Configurations::ConfigurationSettings");
    static const QLatin1String TrustedContact ("Configurations::TrustedContact");
    static const QLatin1String TrustedContactNumber ("Configurations::TrustedContactNumber");
    static const QLatin1String AutomaticTimeout ("Configurations::AutomaticTimeout");
    static const QLatin1String EraseDeviceType ("Configurations::EraseDeviceType");
    static const QLatin1String IsEnabled ("Configurations::IsEnabled");
    static const QLatin1String WipingState ("Configurations::WipingState");
    static const QLatin1String LockedState ("Configurations::LockedState");
    static const QLatin1String AllowedFailedAttempts ("Configurations::AllowedFailedAttempts");
    static const QLatin1String AllowRemoteSecurity ("Configurations::AllowRemoteSecurity");
    static const QLatin1String CallStateActive ("Configurations::CallStateActive");
    // Allow an external app to request the settings.
    static const QLatin1String RequestSettings ("Configurations::RequestSettings");

    // TODO what should we do with this setting
    // Do not store a state in this variable, jsut use it for setting the state of another setting
    static const QLatin1String DeviceState ("Configurations::DeviceState");

    // additional labels for
    static const QLatin1String SenderHeaderLabelList ("Configurations::SenderHeaderLabelList");

    // additional UI parameter, has not to be stored anywhere, needed for UI after DBus calls only
    static const QLatin1String ChainingWin ("Configurations::ChainingWin");
}

#endif // SHARED_SETTINGS_H
